@@ -11,9 +11,10 @@ def main():
     parser = configargparse.ArgumentParser()
     parser.add_argument(
         '--port', type=int, default=4040,
-        env_var='JELLYSUB_HTTP_PORT')
+        env_var='JELLYSUB_HTTP_PORT',
+        help='port to serve on (default: %(default)s)')
     parser.add_argument(
-        '--upstream', type=yarl.URL,
+        '--upstream', type=yarl.URL, metavar='URL',
         env_var='JELLYSUB_UPSTREAM_URL', required=True)
     args = parser.parse_args()
 
